@@ -3,7 +3,7 @@ BEGIN {
   $SyForm::Field::Label::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: A label for the field
-$SyForm::Field::Label::VERSION = '0.009';
+$SyForm::Field::Label::VERSION = '0.010';
 use Moose::Role;
 use namespace::clean -except => 'meta';
 
@@ -13,6 +13,11 @@ has label => (
   predicate => 'has_label',
 );
 
+around viewfield_roles_by_results => sub {
+  my ( $orig, $self, $results ) = @_;
+  return $self->$orig($results), qw( SyForm::ViewField::Label );
+};
+
 1;
 
 __END__
@@ -25,7 +30,7 @@ SyForm::Field::Label - A label for the field
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 AUTHOR
 
